@@ -1,5 +1,5 @@
 package FAIR::Accessor;
-$FAIR::Accessor::VERSION = '0.41';
+$FAIR::Accessor::VERSION = '1.0';
 
 
 
@@ -21,9 +21,9 @@ unless ($ENV{REQUEST_METHOD}){  # if running from command line
     } else {
         $ENV{REQUEST_METHOD} = "GET";
         $ENV{'SERVER_NAME'} =  "example.net";
-        $ENV{'REQUEST_URI'} = "/this/thing";
-        $ENV{'SCRIPT_NAME'} = "/this/thing";
-        $ENV{'PATH_INFO'} = "/1234567";
+        $ENV{'REQUEST_URI'} = "/SemanticPHIBase/Metadata";
+        $ENV{'SCRIPT_NAME'} = "/SemanticPHIBase/Metadata";
+        $ENV{'PATH_INFO'} = "/INT_00000";
     }
 }
 
@@ -85,7 +85,7 @@ FAIR::Accessor - all this does is assign the HTTP call to the correct routine
 
 =head1 VERSION
 
-version 0.41
+version 1.0
 
 =head1 SYNOPSIS
 
@@ -112,7 +112,6 @@ The following code is a complete implementation of a 'Hello, World!' FAIR Access
    localNamespaces => {
 	ontology => 'http://example.org/ontologies/MyOntology#', 
 	},  # add a few new namespaces to the list of known namespaces....
-   localMetadataElements => [qw(hw:Greeting hw2:grusse) ],  # things that we use in addition to common metadata elements
    basePATH => 'Nameof/ThisScript', # REQUIRED regexp to match the RESTful PATH part of the URL, before the ID number
 
  };
@@ -128,7 +127,7 @@ The following code is a complete implementation of a 'Hello, World!' FAIR Access
  #-----------------------------------------------------------------
 
  
- =head2 MetaContainer
+ =head2 Container
   Function: REQUIRED SUBROUTINE - returns the first-stage LD Platform list of contained URIs and the dataset metadata.
   Args    : $starting_at_record : this will be passed-in to tell you what record to start with (for paginated responses)
   $path : the webserver's PATH_INFO environment value (used to modify the behaviour of REST services)
@@ -156,7 +155,7 @@ The following code is a complete implementation of a 'Hello, World!' FAIR Access
  =cut
  
  
- sub MetaContainer {
+ sub Container {
 
    my ($self, %ARGS) = @_;
 
@@ -187,7 +186,7 @@ The following code is a complete implementation of a 'Hello, World!' FAIR Access
  
 
 
- =head2 Distributions
+ =head2 MetaRecord
 
   Function: REQUIRED IF get_all_meta_URIs list of URIs point back to this script.
            returns the second-stage LD Platform metadata describing the DCAT distributions, formats, and URLs
@@ -211,7 +210,7 @@ The following code is a complete implementation of a 'Hello, World!' FAIR Access
  =cut
 
 
- sub Distributions {
+ sub MetaRecord {
    my ($self, %ARGS) = @_;
 
    my $ID = $ARGS{'ID'};
@@ -269,7 +268,7 @@ The following code is a complete implementation of a 'Hello, World!' FAIR Access
    
  } 
 
- sub getDistributionMetadata {
+ sub getRecordMetadata {
   my ($self, $ID) = @_;
   my %metadata = (
         'dcat:description' => "RDF representation of PHI Base Interaction Record PHI:$ID",
