@@ -1,12 +1,13 @@
 package FAIR::AccessorBase;
-$FAIR::AccessorBase::VERSION = '0.41';
+$FAIR::AccessorBase::VERSION = '1.0';
+
+
 
 
 # ABSTRACT: The core Accessor functions
 
 
 use Moose;
-
 use URI::Escape;
 use JSON;
 use FAIR::AccessorConfig;
@@ -15,9 +16,11 @@ use RDF::Trine::Model 0.135;
 use RDF::Trine::Statement 0.135;
 use RDF::Trine::Node::Resource;
 use RDF::Trine::Node::Literal;
+use Scalar::Util 'blessed';
 use Log::Log4perl;
 
 
+with 'FAIR::CoreFunctions';
 
 has 'Configuration' => (
     isa => 'FAIR::AccessorConfig',
@@ -37,8 +40,7 @@ around BUILDARGS => sub {
 
 # ============================================
 #  All Daemons must implement this method
-
-sub get_all_meta_URIs {
+sub Container {
 	my ( @args ) = @_;
 
 	# user-specific implementation will override this method
@@ -47,7 +49,7 @@ sub get_all_meta_URIs {
 # ============================================
 #  Some Daemons may implement this method
 
-sub get_distribution_URIs {
+sub MetaRecord {
 	my ( @args ) = @_;
 
 	# user-specific implementation will override this method
@@ -72,7 +74,7 @@ sub manageContainerGET {
     my $model = RDF::Trine::Model->new($store);
     my $ns = $self->Configuration->Namespaces;
         
-    $self->callMetadataAccessor($BASE_URL, $model);  
+    $self->callAccessorContainer($BASE_URL, $model);  
 
     my $statement = statement($BASE_URL, $ns->rdf("type"), $ns->ldp("BasicContainer")); 
     $model->add_statement($statement);
@@ -86,70 +88,95 @@ sub manageContainerGET {
 }
 
 sub makeSensibleStatement {
-      my ($self, $subject, $predicate, $obj) = @_;
+      my ($self, $s, $p, $o) = @_;
+	my ($subject, $predicate, $object);
       my $NS = $self->Configuration->Namespaces();
-      my ($ns, $pred) = split /:/, $predicate;
-      my $statement;
-      if ($obj =~ /^http:/) {  # if its a URL
-            $statement = statement($subject,  $NS->$ns($pred), $obj); 
-      } elsif ((!($obj =~ /\s/)) && ($obj =~ /\S+:\S+/)){  # if it looks like a qname tag
-            my ($vns,$vobj) = split /:/, $obj;
-            if ($NS->$vns($vobj)) {
-                  $statement = statement($subject,  $NS->$ns($pred), $NS->$vns($vobj));                   
-            } else {
-                  $statement = statement($subject,  $NS->$ns($pred), $obj); 
-            }                             
+      
+      if (($s =~ /^http:/) || ($s =~ /^https:/)) {
+		$subject = $s;
       } else {
-            $statement = statement($subject,  $NS->$ns($pred), $obj); 
+             my ($ns, $sub) = split /:/, $s;
+             $subject = $NS->$ns($sub);   # add the namespace   
       }
+      
+      if (($p =~ /^http:/) || ($p =~ /^https:/)) {
+	$predicate = $p;
+      } else {
+             my ($ns, $pred) = split /:/, $p;
+             $predicate = $NS->$ns($pred);   # add the namespace   
+      }
+         
+      if (($o =~ /^http:/) || ($o =~ /^https:/)) {  # if its a URL
+            $object = $o
+      } elsif ((!($o =~ /\s/)) && ($o =~ /\S+:\S+/)){  # if it looks like a qname tag
+            my ($ns,$obj) = split /:/, $o;
+            if ($NS->$ns($obj)) {
+                  $object =  $NS->$ns($obj);   # add the namespace               
+            }
+      } else {
+		$object = $o
+	}
+         
+      my $statement = statement($subject,  $predicate, $object); 
+      
       return $statement;
       
 }
 
 
-sub callMetadataAccessor {
-    my ($self, $subject, $model) = @_;
-    
-    my $result = $self->MetaContainer(); # this subroutine is provided by the end-user in the Accessor script on the web
-    $result = decode_json($result);
-    
-    $model->begin_bulk_ops();
-    
-    foreach my $CDE(keys %$result){
+sub callAccessorContainer {
+      my ($self, $subject, $model) = @_;
+      
+      my ($Container) = $self->Container(); # this subroutine is provided by the end-user in the Accessor script on the web
+      die "Not a FAIR::Accessor::Container" unless $Container->isa("FAIR::Accessor::Container");
+
+
+      $model->begin_bulk_ops();
+      my %metadata = %{$Container->MetaData};
 
-      next unless $result->{$CDE}; 
-      my $statement;
-      my $values = $result->{$CDE};
-      $values = [$values] unless (ref($values) =~ /ARRAY/);
       my $temprdf;  # doing this to make the import more efficient... I hope!
-      foreach my $value(@$values){
-            $statement = $self->makeSensibleStatement($subject, $CDE, $value);
+      
+      # ADD THE METADATA key/value|array pairs
+      foreach my $CDE(keys %metadata){
+      
+            next unless $metadata{$CDE}; # if it is blank, ignore it
+            
+            my $values = $metadata{$CDE};
+            $values = [$values] unless (ref($values) =~ /ARRAY/);
+            foreach my $value(@$values){
+                  my $statement = $self->makeSensibleStatement($subject, $CDE, $value);
+                  my $str = $statement->as_string;  # almost n3 format... need to fix it a bit...
+                  $str =~ s/^\(triple\s//;
+                  $str =~ s/\)$/./;
+                  $temprdf .= "$str\n";  # this is RDF in n3 format
+            }
+   
+      }
+      
+      # ADD THE RECORD IDS with "contains"
+      my @records = @{$Container->Records};
+      foreach my $rec(@records){
+            my $statement = $self->makeSensibleStatement($subject, "ldp:contains", $rec);
             my $str = $statement->as_string;  # almost n3 format... need to fix it a bit...
             $str =~ s/^\(triple\s//;
             $str =~ s/\)$/./;
             $temprdf .= "$str\n";  # this is RDF in n3 format
       }
+
       my $parser     = RDF::Trine::Parser->new( 'ntriples' );
       $parser->parse_into_model( "http://example.org/", $temprdf, $model );
- 
-    }
-    $model->end_bulk_ops();
-    
-    # this code allows you to constrain the metadata... I don't like this idea anymore...
-    #foreach my $CDE(@{$self->Configuration->MetadataElements}){  # common metadata, plus locally specified metadata elements
-    #    next unless $result->{$CDE};  # this will reject any metadata that you didn't specify in the configuration
-    #    my ($namespace, $term) = split /:/, $CDE;
-    #    
-    #    if (ref($result->{$CDE}) =~ /ARRAY/) {
-    #        foreach (@{$result->{$CDE}}){
-    #            my $statement = statement($subject, $ns->$namespace($term), $_); 
-    #            $model->add_statement($statement);
-    #        }
-    #    } else {                    
-    #        my $statement = statement($subject,$ns->$namespace($term), $result->{$CDE}); 
-    #        $model->add_statement($statement);
-    #    }
-    #}
+      
+      
+      $model->end_bulk_ops();
+            
+
+      if ($Container->FreeFormRDF && blessed($Container->FreeFormRDF) && $Container->FreeFormRDF->isa("RDF::Trine::Model")) {  # if they are doing this, they know what they are doing!  (we assume)
+            my $iterator = $Container->FreeFormRDF->statements;
+            while (my $stm = $iterator->next()) {
+                 $model->add_statement($stm);
+           }
+      }            
+
 }
 # ====================== END OF STAGE1 SUBROUTINES
 
@@ -173,93 +200,67 @@ sub manageResourceGET {  # $self->manageResourceGET('PATH' => $path, 'ID' => $id
 
 
 sub callDataAccessor {
-    my ($self, $model, $ID) = @_;
-
+      my ($self, $model, $ID) = @_;
+      
       # call out to user-provided subroutine
-    my $result = $self->Distributions('ID' => $ID);
-    $result = decode_json($result);
+      my ($MetaRecord) = $self->MetaRecord('ID' => $ID);  # this method is provided (hopefully) by the service provider's Accessor script.
+      # TODO - this should be a catch, not a call...
+      
+      
+      my $subject = "http://" . $ENV{'SERVER_NAME'} . $ENV{'REQUEST_URI'};
+      my $NS = $self->Configuration->Namespaces();
 
-    my $URL = "http://" . $ENV{'SERVER_NAME'} . $ENV{'REQUEST_URI'};
-    my $NS = $self->Configuration->Namespaces();
+      #----------------------------------------------------------------------------------
+      #  GENERIC METADATA----------------------------------------------------------------
+      #----------------------------------------------------------------------------------
 
-    my $distributions = $result->{'distributions'};
-      foreach my $format(keys %$distributions){
-            next unless ($format =~ /\S/);
-            my $location = $distributions->{$format};
-            $location = [$location] unless (ref($location) =~ /ARRAY/);  # force it to be always be an arrayref just for code clarity
+      my %metadata = %{$MetaRecord->MetaData};      
+      foreach my $CDE(keys %metadata){            
+            next unless $metadata{$CDE}; # if it is blank, ignore it
             
-            foreach my $loc(@$location){
-                  next unless ($loc =~ /\S/);
-                  my $statement = statement($URL, $NS->dcat('distribution'), $loc);
-                  $model->add_statement($statement);
-                  
-                  $statement = statement($loc, $NS->rdf('type'), $NS->dcat('Distribution'));
-                  $model->add_statement($statement);
-                  
-                  $statement = statement($loc, $NS->rdf('type'), $NS->dctypes('Dataset'));
-                  $model->add_statement($statement);
-
-                  $statement = statement($loc, $NS->dc('format'), $format);
-                  $model->add_statement($statement);
-
-                  if (($format =~ /turtle/) || ($format =~ /rdf/) || ($format =~ /quads/)) {
-                        $statement = statement($loc, $NS->rdf('type'), $NS->void('Dataset'));
-                        $model->add_statement($statement);
-                  }
-                  
-            
-                  $statement = statement($loc, $NS->dcat('downloadURL'), $loc);
+            my $values = $metadata{$CDE};
+            $values = [$values] unless (ref($values) =~ /ARRAY/);
+            foreach my $value(@$values){
+                  my $statement = $self->makeSensibleStatement($subject, $CDE, $value);
                   $model->add_statement($statement);
             }
       }
-                   
-        
-      my $metadata = $result->{'metadata'};
-      if ($metadata && keys %$metadata) {
       
-            foreach my $predicate(keys %$metadata){
-                  my $values = $metadata->{$predicate};
-                  $values = [$values] unless (ref($values) =~ /ARRAY/);
-                                    
-                  foreach my $value(@$values) {
-                        my $statement = $self->makeSensibleStatement($URL, $predicate, $value);
-                        $model->add_statement($statement);                               
-                  }
+      
+      #----------------------------------------------------------------------------------      
+      # DISTRIBUTION METADATA ---------------------------------------------
+      #----------------------------------------------------------------------------------
+
+      my $distributions = $MetaRecord->Distributions();
+      foreach my $Dist(@$distributions){
+            my $downloadURL = $Dist->downloadURL();
+            my $statement = $self->makeSensibleStatement($subject, $NS->dcat('distribution'), $downloadURL);
+            $model->add_statement($statement);
+            my $projector = 0;
+            foreach my $type($Dist->types){
+                  $statement = $self->makeSensibleStatement($downloadURL, $NS->rdf('type'), $type);
+                  $model->add_statement($statement);
+                  $projector = 1 if ($type =~ /Projector/);  # flag it as a projector for the if block below                  
             }
-      }
-      
-      # okay, $model is now full!
-}
-
-
-sub statement {
-	my ($s, $p, $o) = @_;
-	unless (ref($s) =~ /Trine/){
-		$s =~ s/[\<\>]//g;
-		$s = RDF::Trine::Node::Resource->new($s);
-	}
-	unless (ref($p) =~ /Trine/){
-		$p =~ s/[\<\>]//g;
-		$p = RDF::Trine::Node::Resource->new($p);
-	}
-	unless (ref($o) =~ /Trine/){
-
-		if ($o =~ /^http\:\/\// || $o =~ /^https\:\/\//){
-			$o = RDF::Trine::Node::Resource->new($o);
-		} elsif ($o =~ /^<http\:\/\//){
-			$o =~ s/[\<\>]//g;
-			$o = RDF::Trine::Node::Resource->new($o);
-		} elsif ($o =~ /"(.*?)"\^\^\<http\:/) {
-			$o = RDF::Trine::Node::Literal->new($1);
-		} else {
-			$o = RDF::Trine::Node::Literal->new($o);				
+            
+	    foreach my $form(@{$Dist->availableformats}){
+	            $statement = $self->makeSensibleStatement($downloadURL, $NS->dc('format'), $form);
+	            $model->add_statement($statement);            
 		}
-	}
-	my $statement = RDF::Trine::Statement->new($s, $p, $o);
-	return $statement;
+      
+            $statement = $self->makeSensibleStatement($downloadURL, $NS->dcat('downloadURL'), $downloadURL);
+            $model->add_statement($statement);
+            
+            if ($projector) {
+                  my $projectionmodel = $Dist->ProjectionModel();
+                  $model->add_iterator($projectionmodel->as_stream);
+            }
+            
+      }
 }
 
 
+
 sub printResourceHeader {
 	my ($self) = @_;
         my $ETAG = $self->Configuration->ETAG_Base();
@@ -351,7 +352,7 @@ FAIR::AccessorBase - The core Accessor functions
 
 =head1 VERSION
 
-version 0.41
+version 1.0
 
 =head1 AUTHOR
 
