@@ -1,5 +1,5 @@
 package FAIR::AccessorConfig;
-$FAIR::AccessorConfig::VERSION = '0.41';
+$FAIR::AccessorConfig::VERSION = '1.0';
 
 
 # ABSTRACT: The key/value of the current configuration of the Accessor
@@ -13,33 +13,6 @@ use RDF::NS '20131205';              # check at compile time
 # define common metadata elements here, and their namespaces
 
 
-my @CDE = qw(
-    dcat:contactPoint
-    dcat:description
-    dcat:distribution
-    dcat:frequency
-    dcat:identifier
-    dcat:keyword
-    dcat:landingPage
-    dcat:language
-    dcat:publisher
-    dcat:releaseDate
-    dcat:spatial
-    dcat:temporal
-    dcat:theme
-    dcat:license
-    dc:title
-    dcat:updateDate
-    void:entities
-    daml:has-Technical-Lead
-    daml:has-Administrative-Contact
-    daml:has-Program-Manager
-    daml:has-Principle-Investigator
-    
-    ldp:contains
-
-);
-
 has 'title' => (
     isa => 'Str',
     is  => 'rw',
@@ -80,10 +53,6 @@ has 'localNamespaces' => (
     is => 'rw',
 );
 
-has 'localMetadataElements' => (
-    isa => 'ArrayRef[Str]',
-    is => 'rw',
-);
 
 has 'Namespaces' => (
     isa => "RDF::NS",
@@ -96,13 +65,6 @@ has 'ETAG_Base' => (
     is => "rw",
 );
 
-has 'MetadataElements' => (
-    isa => 'ArrayRef[Str]',
-    is => 'rw',
-);
-
-
-
 	
 
 sub BUILD {
@@ -118,6 +80,10 @@ sub BUILD {
     die "can't set namespace $!\n" unless ($NS->SET(pav => 	'http://purl.org/pav/'));
     die "can't set namespace $!\n" unless ($NS->SET(schemaorg => 'http://schema.org/'));
     die "can't set namespace $!\n" unless ($NS->SET(void => 'http://rdfs.org/ns/void#'));
+    die "can't set namespace $!\n" unless ($NS->SET(fair => 'http://datafairport.org/ontology/FAIR-schema.owl#'));
+    die "can't set namespace $!\n" unless ($NS->SET(rr => 'http://www.w3.org/ns/r2rml#'));
+    die "can't set namespace $!\n" unless ($NS->SET(rml => 'http://semweb.mmlab.be/ns/rml#'));
+    die "can't set namespace $!\n" unless ($NS->SET(ql => 'http://semweb.mmlab.be/ns/ql#'));
 
     foreach my $abbreviation(keys %{$self->localNamespaces()}){
 	my $namespace = $self->localNamespaces()->{$abbreviation};
@@ -125,8 +91,7 @@ sub BUILD {
 	    print STDERR  "Failed to set namespace $abbreviation  ==  $namespace   Make sure your abbreviation has no capital letters (Perl library quirk!)";
 	}
     }
-    my @MetaDataElements = (@CDE, @{$self->localMetadataElements()});
-    $self->MetadataElements(\@MetaDataElements);  # concatinate local with common metadata elements
+
     
 }
 
@@ -144,7 +109,7 @@ FAIR::AccessorConfig - The key/value of the current configuration of the Accesso
 
 =head1 VERSION
 
-version 0.41
+version 1.0
 
 =head1 AUTHOR
 
